function SceneMovie(options)
{
	this.options = options;
    this.selfState = new Object();
    this._focusable = false;
}

SceneMovie.prototype.initialize = function ()
{
	alert("SceneMovie.initialize()");
}

SceneMovie.prototype.buildList = function (obj)
{
    if (obj.type != "movie_card" && obj.type != "series_card")
    {
        $.sfScene.get("Main").showError("Movie", "Przepraszamy, wystąpił błąd serwera [4x1].");
        return false;
    }
    
    this.selfState.caption = obj.title;
    
    this.resetButtons(true);
    
    if (typeof obj.lector != "undefined")
    {
        $("#btnLector").data("url", obj.lector).show();
    }
    
    if (typeof obj.subtitles != "undefined")
    {
        $("#btnSubtitles").data("url", obj.subtitles).show();
    }
    
    if (typeof obj.series != "undefined")
    {
        $("#btnSeries").data("url", obj.series).show();
    }
    
    $("#movieCover").attr("src", "");
    $("#movieCover").attr("src", obj.img);
    $("#movieTitle").html(obj.title);
    $("#movieCountry").html("").html(obj.country);
    $("#movieYear").html("").html(obj.year);
    if (typeof obj.duration == "number")
    {
        $("#movieDuration").html(obj.duration + " min.").parent().show();
        $("#movieCount").parent().hide();
    }
    else if (typeof obj.movies_count == "number")
    {
        $("#movieCount").html(obj.movies_count + " odc.").parent().show();
        $("#movieDuration").parent().hide();
    }
    if (typeof obj.age_limit == "number")
    {
        if (obj.age_limit == 0)
        {
            $("#movieAgeLimit").html("Brak ograniczeń");
        }
        else
        {
            $("#movieAgeLimit").html(obj.age_limit+"+");
        }
    }
    else
    {
        $("#movieAgeLimit").html("Brak danych");
    }
    $("#movieGenres").html("").html(obj.genres);
    $("#movieDirector").html("").html(obj.director);
    $("#movieScenario").html("").html(obj.scenario);
    $("#movieActors").html("").html(obj.actors);
    $("#movieDescription").html("").html(obj.description.nl2br());
    $("#movieDescRightPane").scrollTop(0);
    
    $("#movieLoading").hide();
    $("#movieWrapper").show();
    
    $("#movieDescScroller").sfScrollbar2(
    {
        contentHeight: $("#movieDescScrollerWrapper").height(),
        contentWrapperHeight: $("#movieDescRightPane").height(),
        contentScrollAmount: conf.descScrollAmount,
        scrollerHeight: $("#movieDescScroller").height()
    });
    
    this.helpBar("playlist");
    
    this._focusable = true;
    
    return true;
}

SceneMovie.prototype.sendRequestForData = function (obj)
{
    $("#movieWrapper").hide();
    $("#movieLoading").show();
    
    this._focusable = false;
    this.selfState = obj;
    var caller = this;
    
    movieXHR =  $.sfScene.get("Main").getXHRObj("Movie");
    movieXHR.sendXHRRequest(this.selfState.url, function (result, respObj)
    {
        if (result)
        {
            caller.buildList($.parseJSON(respObj.responseText));
            return true;
        }
        else
        {
            $.sfScene.get("Main").showError("Movie", "Przepraszamy, wystąpił błąd z połączeniem [4x0].<br />Prosimy spróbować ponownie za chwilę.");
            return false;
        }
    });
}

SceneMovie.prototype.helpBar = function (type)
{
        var helpbar = new Object();
        
        if ($("#btnSeries").css("display") == "block")
        {
            helpbar["red"] = "Pokaż odcinki";
        }
        
        if ($("#btnSubtitles").css("display") == "block")
        {
            helpbar["green"] = "Napisy";
        }
        
        if ($("#btnLector").css("display") == "block")
        {
            helpbar["blue"] = "Lektor";
        }
        
        if ($("#btnSeries").css("display") == "block")
        {
            helpbar["enter"] = "Pokaż odcinki";
        }
        else if ($("#btnLector").css("display") == "block")
        {
            helpbar["enter"] = "Lektor";
        }
        else if ($("#btnSubtitles").css("display") == "block")
        {
            helpbar["enter"] = "Napisy";
        }
        
        if ($("#movieDescScroller").isVisible() && type == "playlist")
        {
            helpbar["leftright"] = "Przewiń opis filmu";
        }
        else if ($("#movieDescScroller").isVisible() && type == "movie_card")
        {
            helpbar["updown"] = "Przewiń opis filmu";
        }
        
        if (type == "playlist")
        {
            helpbar["updown"] = "Wybierz film";
        }
        else if (type == "movie_card")
        {
            helpbar["leftright"] = "Przejdź do listy filmów";
        }
        
        var prevScene = $.sfScene.get("Main").prevScene;
        
        if (prevScene.length == 0)
        {
            helpbar["return"] = "Wyjdź";
        }
        else
        {
            if (typeof prevScene[prevScene.length - 1].caption == "")
            {
                helpbar["return"] = "Wróć";
            }
            else
            {
                helpbar["return"] = "Wróć do " + prevScene[prevScene.length - 1].caption;
            }
        }
        
        $.sfScene.get("Main").helpBar(helpbar);
}

SceneMovie.prototype.resetButtons = function (hide)
{
    if (hide)
    {
        $("#btnLector").data("url", "").hide();
        $("#btnSubtitles").data("url", "").hide();
        $("#btnSeries").data("url", "").hide();
    }
    else
    {
        $("#btnLector").data("url", "");
        $("#btnSubtitles").data("url", "");
        $("#btnSeries").data("url", "");
    }
}

SceneMovie.prototype.setFocusable = function (focusable)
{
    this._focusable = focusable;
}

SceneMovie.prototype.getFocusable = function ()
{
    return (this._focusable && $("#movieDescScroller").isVisible());
}

SceneMovie.prototype.handleShow = function ()
{
	alert("SceneMovie.handleShow()");
}

SceneMovie.prototype.handleHide = function ()
{
    alert("SceneMovie.handleHide()");

    this.resetButtons(true);
    
    $("#movieCount").html("").parent().hide();
    $("#movieDuration").html("").parent().hide();
    
    $("#movieDescLabel").html("");
    $("#movieCover").attr("src", "");
    $("#movieDescRightPane span.value").html("");
    $("#movieDescRightPane").scrollTop(0);
    
    $("#movieWrapper").hide();
    
    $.sfScene.get("Main").getXHRObj("Movie").abortXHRObj();
}

SceneMovie.prototype.handleFocus = function ()
{
	alert("SceneMovie.handleFocus()");
    
    if (this.getFocusable())
    {
        $("#movieDescScroller").sfScrollbar2("focus");
        this.helpBar("movie_card");
    }
    else
    {
        this.handleKeyDown($.sfKey.LEFT);
    }
}

SceneMovie.prototype.handleBlur = function ()
{
	alert("SceneMovie.handleBlur()");
    
    $("#movieDescScroller").sfScrollbar2("blur");
}

SceneMovie.prototype.handleKeyDown = function (keyCode)
{
	alert("SceneMovie.handleKeyDown(" + keyCode + ")");
    
	switch (keyCode)
    {
		case $.sfKey.LEFT:
            this.helpBar("playlist");
            $.sfScene.focus("NavigationMenuMovies");
			break;
            
            
		case $.sfKey.UP:
            $("#movieDescRightPane").scrollTop($("#movieDescRightPane").scrollTop() - conf.descScrollAmount);
            $("#movieDescScroller").sfScrollbar2("move", "up");
			break;
            
		case $.sfKey.DOWN:
            $("#movieDescRightPane").scrollTop($("#movieDescRightPane").scrollTop() + conf.descScrollAmount);
            $("#movieDescScroller").sfScrollbar2("move", "down");
			break;
            
            
		case $.sfKey.GREEN:
            if ($("#btnSubtitles").data("url") != "")
            {
                var newScene = new Object();
                newScene.url = $("#btnSubtitles").data("url");
                newScene.caption = this.selfState.caption;
                newScene.type = "video";
                newScene.cursor = 0;
                
                $.sfScene.get("Main").sendRequestForData(newScene, $.sfScene.get("NavigationMenuMovies").selfState);
            }
			break;
            
		case $.sfKey.BLUE:
            if ($("#btnLector").data("url") != "")
            {
                var newScene = new Object();
                newScene.url = $("#btnLector").data("url");
                newScene.caption = this.selfState.caption;
                newScene.type = "video";
                newScene.cursor = 0;
                
                $.sfScene.get("Main").sendRequestForData(newScene, $.sfScene.get("NavigationMenuMovies").selfState);
            }
			break;
            
		case $.sfKey.RED:
            if ($("#btnSeries").data("url") != "")
            {
                var newScene = new Object();
                newScene.url = $("#btnSeries").data("url");
                newScene.caption = this.selfState.caption;
                newScene.type = "playlist";
                newScene.cursor = 0;
            
                $.sfScene.get("Main").sendRequestForData(newScene, $.sfScene.get("NavigationMenuMovies").selfState);
            }
			break;
            
		case $.sfKey.ENTER:
            if ($("#btnSeries").data("url") != "")
            {
                this.handleKeyDown($.sfKey.RED);
            }
            else if ($("#btnLector").data("url") != "")
            {
                this.handleKeyDown($.sfKey.BLUE);
            }
            else if ($("#btnSubtitles").data("url") != "")
            {
                this.handleKeyDown($.sfKey.GREEN);
            }
			break;
            
            
        case $.sfKey.RETURN:
            $.sfKey.block();
            $.sfScene.get("Main").goBack();
            break;
	}
}
